@@ -52,35 +52,24 @@ jQuery.fn.liveCheckboxes = function () {
 
 
 
-/* Shows an OpenLayer popup, data must have the following properties:
+/* Shows an "jquery tools overlay" popup, data must have the following properties:
+data.html
+
+Previously it also needed:
 data.id
 data.x
 data.y
-data.html
 data.big
+But those aren't used anymore.
 */
+
 function show_popup(data, map) {
     if (data.html !== "" && data.html !== undefined) {
-        var size, popup;
-        $("#" + data.id).remove(); // remove existing popup, if exists
-        size = new OpenLayers.Size(400, 340);
-        if (data.big) {
-            size = new OpenLayers.Size(420, 610);
-        }
-        popup = new OpenLayers.Popup(
-            data.id,
-            new OpenLayers.LonLat(data.x, data.y),
-            size,
-            data.html + '<span class="no-hover-popups"></span>',
-            true);
-        popup.panMapIfOutOfView = true;
-        map.addPopup(popup);
-        // make sure that when the window is closed, the object is removed as well
-        $(".olPopupCloseBox").bind("click", function () {
-            $(this).parent().parent().remove();
-        });
+        var overlay;
+        $('#graph-popup-content').html(data.html);
+        overlay = $('#graph-popup').overlay();
+        overlay.load();
         reloadGraphs();
-        // tijdelijk, hoeft niet meer als add-snippet live kan worden gebruikt
         $(".add-snippet").snippetInteraction();
     }
     else {
@@ -88,27 +77,22 @@ function show_popup(data, map) {
     }
 }
 
+
 function hover_popup(data, map) {
     if (data.name !== "" &&
-        data.name !== undefined &&
-        $('.no-hover-popups').size() === 0) {
-        var size, popup;
+        data.name !== undefined) {
+        var size, popup, content;
+        content = '&nbsp;&nbsp;&nbsp;&nbsp;' + data.name +
+            '&nbsp;&nbsp;&nbsp;&nbsp;';
         $("#hover-popup").remove(); // remove existing popup, if exists
         size = new OpenLayers.Size(300, 80);
         popup = new OpenLayers.Popup('hover-popup',
                                      new OpenLayers.LonLat(data.x, data.y),
                                      size,
-                                     data.name,
+                                     content,
                                      false);
         popup.autoSize = true;
         map.addPopup(popup);
-        // make sure that when the window is closed, the object is removed as well
-        $(".olPopupCloseBox").bind("click", function () {
-            $(this).parent().parent().remove();
-        });
-        reloadGraphs();
-        // tijdelijk, hoeft niet meer als add-snippet live kan worden gebruikt
-        $(".add-snippet").snippetInteraction();
     }
 }
 
@@ -230,6 +214,8 @@ jQuery.fn.workspaceInteraction = function () {
         $workspace.workspaceTrashBox();
         // Make checkboxes work.
         $workspace.liveCheckboxes();
+        // Initialize the graph popup.
+        $('#graph-popup').overlay({});
     });
 };
 
